@@ -1,8 +1,3 @@
-library(bayesnec)
-library(brms)
-
-data(manec_example)
-
 test_that("nec returns expected object types", {
   nec_summary <- suppressMessages(nec(manec_example))
   expect_equal(length(nec_summary), 3)
